<?php
/* @var $this NewsletterAmazon */
require_once NEWSLETTER_INCLUDES_DIR . '/controls.php';
$controls = new NewsletterControls();
$mailer = $this->get_mailer();

if (!class_exists('\Aws\Sdk')) {
    require_once dirname(__FILE__) . '/api/aws-autoloader.php';
} else {
    if (version_compare(\Aws\Sdk::VERSION, '3', '>=')) {
        $controls->warnings[] = 'The Amazon Services connection kit is already included by another plugin. There should be no problems if they load the whole Amazon SDK.';
    } else {
        $controls->warnings[] = 'The Amazon Services connection kit is already included by another plugin but it is an old version. There could be important delivery issues.';
    }
}

if (is_plugin_active('pixel-caffeine/pixel-caffeine.php')) {
    $controls->warnings[] = 'The plugin Pixel Caffeine is active and contains only a partial version of the official Amazon SDK. That could interfere with this addon. You should ask the authors to include the whole Amazon SDK.';
}

if (is_plugin_active('backwpup/backwpup.php')) {
    $controls->warnings[] = 'The plugin BackWPup is active and contains only a partial version of the official Amazon SDK. That could interfere with this addon. You should ask the authors to include the whole Amazon SDK.';
}


require_once dirname(__FILE__) . '/api/regions.inc.php';

use Aws\Common\Aws;

$newsletter = Newsletter::instance();

$logger = new NewsletterLogger('amazon');

if (!$controls->is_action()) {
    $controls->data = $this->options;
} else {

    if ($controls->is_action('save')) {
        $this->save_options($controls->data);
        $controls->messages = 'Saved.';
    }

    if ($controls->is_action('reset')) {
        $this->save_last_run(0);
        $controls->messages = 'Done.';
    }

    if ($controls->is_action('test')) {

        $this->save_options($controls->data);

        if (!empty($this->options['turbo'])) {
            $messages = $this->get_test_messages($controls->data['test_email'], $this->options['turbo']);

            $result = $mailer->send_batch_with_stats($messages);

            if (is_wp_error($result)) {
                $controls->errors .= '<strong>Delivery error.</strong> ';
                $controls->errors .= '<strong>Please check if your account is in SANDBOX MODE <a href="https://docs.aws.amazon.com/ses/latest/DeveloperGuide/request-production-access.html" target="_blank">following this Amazon AWS guide</a></strong>.';
                $controls->errors .= '<br><pre style="font-size: .8em">' . esc_html($result->get_error_message()) . '</pre><br>';

                foreach ($messages as $message) {
                    $controls->errors .= 'Error: ' . esc_html($message->error) . '<br>';
                }
            } else {
                $controls->messages = 'Success. You should see ' . $this->options['turbo'] . ' test messages in the selected mailbox.';
                $controls->messages .= '<br>Max speed: ' . $mailer->get_capability() . ' emails per hour';
            }
        } else {
            $message = $this->get_test_message($controls->data['test_email']);
            $result = $mailer->send_with_stats($message);
            if (is_wp_error($result)) {
                $controls->errors .= '<strong>Delivery error.</strong> ';
                $controls->errors .= '<strong>Please check if your account is in SANDBOX MODE <a href="https://docs.aws.amazon.com/ses/latest/DeveloperGuide/request-production-access.html" target="_blank">following this Amazon AWS guide</a></strong>.';
                $controls->errors .= '<br><pre style="font-size: .8em">' . esc_html($result->get_error_message()) . '</pre><br>';
            } else {
                $controls->messages = 'Success.';
                $controls->messages .= '<br>Max speed: ' . $mailer->get_capability() . ' emails per hour';
            }
        }
    }

    if ($controls->is_action('sns_setup') || $controls->is_action('bounce_reset')) {

        try {

            $sns_client = $this->getSnsClient();

            if (is_null($sns_client)) {
                $controls->errors = 'Error creating SNS client, check AWS credentials provided.<br>';
            } else {

                $topic_name = $this->generate_topic_name();

                // find and delete existing topics
                if ($controls->is_action('bounce_reset')) {

                    $topic_list = $sns_client->listTopics()->get('Topics');

                    foreach ($topic_list AS $t) {
                        if (in_array(NewsletterAmazon::$instance->get_topic_name_from_topic_ARN($t['TopicArn']), [$topic_name, 'wp_newsletter_bounce'])) {
                            $sns_client->deleteTopic(array('TopicArn' => $t['TopicArn']));
                        }
                    }
                }

                // Create the topic
                $result = $sns_client->createTopic(array('Name' => $topic_name));

                $logger->debug(print_r($result, true));
                $topic_arn = $result->get('TopicArn');
                $logger->debug('Created topic ARN: ' . $topic_arn);

                if (empty($topic_arn)) {
                    $controls->errors = "Unable to create Amazon SNS topic.";
                } else {

                    $controls->messages = 'Topic created.<br>';

                    $controls->data['bounce_topic_arn'] = $topic_arn;

                    // subscribe to the topic
                    $result = $sns_client->subscribe(array(
                        'TopicArn' => $topic_arn,
                        'Protocol' => stripos($this->notification_endpoint, 'https') === 0 ? 'https' : 'http',
                        'Endpoint' => $this->notification_endpoint,
                    ));

                    $logger->debug('--- Subscription result ---');
                    $logger->debug($result);

                    $subscription_arn = $result->get('SubscriptionArn');
                    if (empty($subscription_arn)) {
                        $controls->errors = "Unable to subscribe to the topic.";
                    } else {
                        $controls->messages .= 'Topic subscribed.<br>';

                        $ses_client = $this->getSesClient();

                        // check identities
                        $address = $newsletter->options['sender_email'];
                        $domain = substr($address, strrpos($address, '@') + 1);
                        // find email identity
                        $identities = $ses_client->listIdentities(['IdentityType' => 'EmailAddress'])->get('Identities');
                        $logger->debug('Email identities: ');
                        $logger->debug(print_r($identities, true));
                        if (!empty($identities)) {
                            if (in_array($address, $identities)) {
                                $identity = $address;
                            }
                        }

                        if (empty($identity)) { // find domain identity
                            $identities = $ses_client->listIdentities(['IdentityType' => 'Domain'])->get('Identities');
                            $logger->debug('Domain identities: ');
                            $logger->debug(print_r($identities, true));
                            if (!empty($identities)) {
                                if (in_array($domain, $identities)) {
                                    $identity = $domain;
                                }
                            }
                        }

                        if (empty($identity)) {
                            $controls->errors = "Sender email (or domain) not verified, please check your sender address.";
                        } else {

                            // set as bounce topic on SES
                            $result = $ses_client->setIdentityNotificationTopic(array(
                                'Identity' => $identity,
                                'NotificationType' => 'Bounce',
                                'SnsTopic' => $topic_arn,
                            ));

                            // set as complaints topic on SES
                            $result = $ses_client->setIdentityNotificationTopic(array(
                                'Identity' => $identity,
                                'NotificationType' => 'Complaint',
                                'SnsTopic' => $topic_arn,
                            ));

                            $controls->messages .= 'Topic set for SES bounce notifications.<br>';
                        }
                    }
                }
            }
        } catch (Exception $e) {
            $controls->errors .= '<small>' . $e->getMessage() . '</small><br>';
        }

        $this->save_options($controls->data);
    }
}

$current_mailer = Newsletter::instance()->get_mailer();
if (isset($controls->data['enabled']) && get_class($current_mailer) != get_class($mailer) && !empty($controls->data['enabled'])) {
    $controls->warnings[] = 'There is another integration active ' . $current_mailer->get_description();
}

if (class_exists('NewsletterBounce')) {
    $controls->warnings[] = 'The Bounce Addon is active, but bounces are managed by this addon: you should deactivate it.';
}
?>

<div class="wrap" id="tnp-wrap">

    <?php include NEWSLETTER_DIR . '/tnp-header.php' ?>

    <div id="tnp-heading">

        <h2>Newsletter Amazon SES Integration</h2>

        <?php $controls->show(); ?>

    </div>

    <div id="tnp-body">

        <form action="" method="post">
            <?php $controls->init(); ?>

            <div id="tabs">
                <ul>
                    <li><a href="#tabs-settings">Settings</a></li>
                    <li><a href="#tabs-bounces">Bounces</a></li>
                </ul>

                <div id="tabs-settings">

                    <table class="form-table">
                        <tr valign="top">
                            <th>Enabled?</th>
                            <td>
                                <?php $controls->yesno('enabled'); ?>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Access Key ID</th>
                            <td>
                                <?php if (defined('NEWSLETTER_AMAZON_KEY')) { ?>
                                    The AWS key is globally defined in your blog configuration file.
                                <?php } else { ?>
                                    <?php $controls->text('aws_key', 50); ?>
                                <?php } ?>
                                <p class="description">You can generate an API key from AWS console, see <a
                                        href="http://www.thenewsletterplugin.com/plugins/newsletter/amazon-ses-extension"
                                        target="_blank">documentation</a>.</p>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Secret Access Key</th>
                            <td>
                                <?php if (defined('NEWSLETTER_AMAZON_KEY')) { ?>
                                    The AWS secret is globally defined in your blog configuration file.
                                <?php } else { ?>
                                    <?php $controls->text('aws_secret', 50); ?>
                                <?php } ?>
                                <p class="description">You can generate an API key from AWS console, see <a
                                        href="http://www.thenewsletterplugin.com/plugins/newsletter/amazon-ses-extension"
                                        target="_blank">documentation</a>.</p>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Service Region</th>
                            <td>
                                <?php $controls->select('aws_region', $ses_regions); ?>
                                <p class="description">To reduce data latency in your applications, most Amazon Web
                                    Services products allow you to select a regional endpoint to make your requests.</p>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Max mails per hour</th>
                            <td>
                                <?php $controls->text('speed'); ?>
                                <p class="description">
                                    Leave empty to use Newsletter main setting.
                                </p>
                            </td>
                        </tr>
                        <tr>
                            <th>Current Sender Address
                                <span class="tip-button">Tip</span>
                                <span class="tip-content">
                                    Amazon requires this address to be verified on SES console in order to use it as your sender.
                                </span>
                            </th>
                            <td>
                                <strong><?php echo $newsletter->options['sender_email'] ?></strong>
                                (<a href="admin.php?page=newsletter_main_main">Change it</a>)<br><br>
                                <?php
                                $nonce = wp_create_nonce("newsletter_amazon_checkaddr_nonce");
                                $link = admin_url('admin-ajax.php?action=newsletter_amazon_checkaddr&nonce=' . $nonce);
                                ?>
                                <a class="button-primary" id="tnp_checkaddr"
                                   data-nonce="<?php echo $nonce ?>" href="<?php echo $link; ?>">
                                    Check verification status
                                </a>
                                <span id="checkaddr_result" style="padding: 5px;"><img id="tnp_loading"
                                                                                       src="images/loading.gif"
                                                                                       style="display: none"/></span>
                                    <?php
                                    $nonce = wp_create_nonce("newsletter_amazon_verifyaddr_nonce");
                                    $link = admin_url('admin-ajax.php?action=newsletter_amazon_verifyaddr&nonce=' . $nonce);
                                    ?>
                                <a class="button-primary" style="display: none" id="tnp_verifyaddr"
                                   data-nonce="<?php echo $nonce ?>" href="<?php echo $link; ?>">
                                    Request verification
                                </a>
                            </td>
                        </tr>
                        <?php if (!empty($newsletter->options['reply_to'])) { ?>
                            <tr>
                                <th>Reply To</th>
                                <td>
                                    <?php echo $newsletter->options['reply_to'] ?>
                                    (<a href="admin.php?page=newsletter_main_main">Change it</a>)
                                </td>
                            </tr>
                        <?php } ?>
                        <?php if (!empty($newsletter->options['return_path'])) { ?>
                            <tr>
                                <th>Return Path
                                    <span class="tip-button">Tip</span>
                                    <span class="tip-content">
                                        This email address must be either individually verified with Amazon SES, or from a domain that has been verified with Amazon SES.
                                    </span>
                                </th>
                                <td>
                                    <?php echo $newsletter->options['return_path'] ?>
                                    (<a href="admin.php?page=newsletter_main_main">Change it</a>)
                                </td>
                            </tr>
                        <?php } ?>

                        <tr>
                            <th>
                                Turbo send
                                <?php $controls->help('https://www.thenewsletterplugin.com/documentation/amazon-extension#turbo') ?>
                            </th>
                            <td>
                                <?php
                                $controls->select('turbo', array('' => 'Disabled',
                                    '2' => '2 processors',
                                    '3' => '3 processors',
                                    '4' => '4 processors',
                                    '5' => '5 processors',
                                    '6' => '6 processors',
                                    '7' => '7 processors',
                                    '8' => '8 processors',
                                    '9' => '9 processors',
                                    '10' => '10 processors'));
                                ?>
                                <p class="description">
                                    NOT IN ALL SYSTEMS THIS OPTION WORKS. USE AT YOUR OWN RISK. WE'RE WORKING TO
                                    DETECTING WHEN IT IS SAFE TO BE USED.
                                    IF ENABLED CHECK THE SERVER ERROR LOGS AND DISABLE IT IF YOU CAN SEE ERRORS RELATED
                                    TO THIS EXTENSION.
                                </p>
                            </td>
                        </tr>

                        <tr>
                            <th>To test this configuration</th>
                            <td>
                                <?php $controls->text_email('test_email', 50); ?>
                                <?php $controls->button('test', 'Send a test message'); ?>
                            </td>
                        </tr>
                    </table>
                </div>


                <div id="tabs-bounces">
                    <p>
                        Amazon SES can notify you of the status of your emails through Amazon Simple Notification
                        Service (Amazon SNS).
                        Verify costs on your Amazon console.
                    </p>
                    <table class="form-table">
                        <tr>
                            <th>Bounce configuration</th>
                            <td>
                                <?php if (empty($controls->data['bounce_topic_arn'])) { ?>
                                    <?php $controls->button('sns_setup', 'Do the magic for me!'); ?> in order to receive bounce notifications
                                    <?php
                                } else {
                                    $nonce = wp_create_nonce("newsletter_amazon_bouncecheck_nonce");
                                    $link = admin_url('admin-ajax.php?action=newsletter_amazon_bouncecheck&nonce=' . $nonce);
                                    ?>
                                    <p><a class="button-primary" id="tnp_bouncecheck"
                                          data-nonce="<?php echo $nonce ?>" href="<?php echo $link; ?>">
                                            Check bounce configuration
                                        </a>
                                        <?php $controls->hidden('bounce_topic_arn'); ?>
                                    </p>
                                    <p id="tnp_bounce_configuration" style="display: none">
                                        <em>Bounce destination</em>: <span id="tnp-bounce-destination"></span><img class="tnp_bounce_loading" src="images/loading.gif" style="display: none"/><br/>
                                        <em>Complaint destination</em>: <span id="tnp-complaint-destination"></span><img class="tnp_bounce_loading" src="images/loading.gif" style="display: none"/><br/>
                                        <em>Newsletter topic on SNS</em>: <span id="tnp-bounce-topic"></span><img class="tnp_bounce_loading" src="images/loading.gif" style="display: none"/><br/>
                                        <em>Topic subscriptions</em>: <span id="tnp-bounce-subscriptions"></span><img class="tnp_bounce_loading" src="images/loading.gif" style="display: none"/>
                                    <div id="tnp-bounce-error"></div>
                                    </p>
                                    <p><?php $controls->button('bounce_reset', 'Reset bounce configuration'); ?></p>
                                <?php } ?>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Process Amazon soft bounces?</th>
                            <td>
                                <?php echo $controls->yesno('process_soft_bounces'); ?><br>
                                In order to process also the complaints, you have to set the same SNS topic for Bounces
                                and Complaints.
                            </td>
                        </tr>
                        <tr valign="top">
                            <th>Last notification processed</th>
                            <td>
                                <?php echo $controls->print_date($this->get_last_run()); ?>
                            </td>
                        </tr>
                    </table>

                </div>

            </div>

            <p>
                <?php $controls->button('save', 'Save'); ?>
            </p>
        </form>
    </div>
    <?php include NEWSLETTER_DIR . '/tnp-footer.php' ?>
</div>

<script type="text/javascript">

    jQuery(document).ready(function () {

        jQuery("#tnp_checkaddr").click(function (event) {
            event.preventDefault();
            aws_key= jQuery("input[name=options\\[aws_key\\]]").val();
            aws_secret= jQuery("input[name=options\\[aws_secret\\]]").val();
            aws_region= jQuery("select[name=options\\[aws_region\\]]").val();
            if (aws_key && aws_secret && aws_region) {
                jQuery('#tnp_loading').show();
                nonce = jQuery(this).attr("data-nonce");
                var data = {
                    action: 'tnp_amazon_checkaddr',
                    nonce: nonce,
                    aws_key: jQuery("input[name=options\\[aws_key\\]]").val(),
                    aws_secret: jQuery("input[name=options\\[aws_secret\\]]").val(),
                    aws_region: jQuery("select[name=options\\[aws_region\\]]").val(),
                };
                jQuery.post(ajaxurl, data, function (response) {
                    jQuery("#checkaddr_result").html(response.message);
                    if (response.valid > 0) {
                        jQuery("#tnp_verifyaddr").hide();
                    } else if (response.valid == 0) {
                        jQuery("#tnp_verifyaddr").fadeIn('fast');
                    }
                }, "json");
            } else {
                jQuery("#checkaddr_result").html("Please fill ID, key and region");
            }
        });

        jQuery("#tnp_verifyaddr").click(function (event) {
            event.preventDefault();
            jQuery('#tnp_loading').show();
            nonce = jQuery(this).attr("data-nonce");
            var data = {
                action: 'tnp_amazon_verifyaddr',
                nonce: nonce,
                aws_key: jQuery("input[name=options\\[aws_key\\]]").val(),
                aws_secret: jQuery("input[name=options\\[aws_secret\\]]").val(),
                aws_region: jQuery("select[name=options\\[aws_region\\]]").val(),
            };
            jQuery.post(ajaxurl, data, function (response) {
                jQuery("#tnp_verifyaddr").hide();
                if (response.valid < 0) {
                    jQuery("#checkaddr_result").html(response.message);
                } else if (response.valid == 0) {
                    jQuery("#checkaddr_result").html(response.message);
                } else {
                    jQuery("#checkaddr_result").html(response.message);
                }
            }, "json");
        });

        jQuery("#tnp_bouncecheck").click(function (event) {
            event.preventDefault();

            jQuery('.tnp_bounce_loading').show();
            jQuery('#tnp_bounce_configuration').show();
            jQuery('#tnp-bounce-topic').html('');
            jQuery('#tnp-bounce-subscriptions').html('');
            jQuery('#tnp-bounce-destination').html('');
            jQuery('#tnp-complaint-destination').html('');

            jQuery('#tnp-bounce-error').html('');

            nonce = jQuery(this).attr("data-nonce");
            var data = {
                action: 'tnp_amazon_bouncecheck',
                nonce: nonce,
            };
            jQuery.post(ajaxurl, data, function (response) {
                jQuery('.tnp_bounce_loading').hide();
                if (response.error) {
                    jQuery('#tnp-bounce-error').html(response.error);
                } else {
                    jQuery('#tnp-bounce-topic').html(response.topicARN);
                    jQuery('#tnp-bounce-subscriptions').html(response.topicSubscriptions);
                    jQuery('#tnp-bounce-destination').html(response.bounceDestination);
                    jQuery('#tnp-complaint-destination').html(response.complaintDestination);
                }
            }, "json");
        });

    });

</script>
