<?php
/*
 * Name: Tribe Events
 * Section: content
 * Description: Extract the latest event from Tribe Events Calendar
 * Type: dynamic
 * 
 */

/* @var $controls NewsletterControls */
/* @var $options array */
/* @var $wpdb wpdb */

if (!class_exists('Tribe__Events__Main')) {
    echo 'The Events Calendar plugin seems not active';
    return;
}

$default_options = array(
    'layout' => 1,
    'image' => 1,
    'max' => 5,
    'show_price' => 1,
    'show_excerpt' => 1,
    'image_size' => 'medium',
    'font_family' => '',
    'font_size' => '',
    'font_weight' => '',
    'font_color' => '',
    'title_font_family' => '',
    'title_font_size' => '',
    'title_font_weight' => '',
    'title_font_color' => '',
    'width' => 600,
    'image_width' => 600,
    'image_height' => 400,
    'image_crop' => 0,
    'button_label' => 'Read more or book now!',
    'button_background' => '',
    'button_font_color' => '',
    'button_font_family' => '',
    'button_font_size' => '',
    'block_padding_left' => 15,
    'block_padding_right' => 15,
    'block_padding_top' => 15,
    'block_padding_bottom' => 15,
    'date_format' => get_option('date_format'),
    'time_format' => get_option('time_format'),
    'automated_no_events' => 'No new events by now!',
    'automated' => '',
    'excerpt_length'=>50);

// Backward compatibility
if (isset($options['automated_required'])) {
    $defaults['automated'] = '1';
}

$options = array_merge($default_options, $options);

$title_style = TNP_Composer::get_title_style($options, 'title', $composer);

$text_style = TNP_Composer::get_text_style($options, '', $composer);

$button_options = TNP_Composer::get_button_options($options, 'button', $composer);

$font_size = $options['font_size'];

$font_family = $options['font_family'];

$options['color'] = '#000';
$color = $options['color'];

$map = isset($options['map']);

if (!empty($options['max']))
    $max = (int) $options['max'];
else
    $max = 10;

if (empty($options['date_format']))
    $options['date_format'] = 'd/m/Y';

$filters = array();
$filters['showposts'] = $max;
$filters['post_type'] = 'tribe_events';
$filters['orderby'] = 'meta_value';
$filters['order'] = 'ASC';

// We check only if there are future events
$filters['meta_key'] = '_EventStartDateUTC';
$filters['meta_value'] = gmdate('Y-m-d H:i:s', time());
$filters['meta_compare'] = '>=';

if (isset($options['tax_tribe_events_cat'])) {
    $filters['tax_query'] = array(
        array(
            'taxonomy' => 'tribe_events_cat',
            'field' => 'term_id',
            'terms' => $options['tax_tribe_events_cat']
        )
    );
}

//if (!empty($context['last_run'])) {
//    $filters['date_query'] = array(
//        'after' => gmdate('c', $context['last_run'])
//    );
//}

$events = get_posts($filters);

// This is a block regeneration with a timestamp
if ($context['type'] == 'automated' && !empty($context['last_run'])) {
    // We don't care the timestamp of the last newsletter sent, we want to send only future events
    if (empty($events)) {
        // I this block was marked as required, we tell the regenerator to return an empty message
        if ($options['automated'] == '1') {
            $out['stop'] = true;
            return;
        } else if ($options['automated'] == '2') {
            $out['skip'] = true;
            return;
        }
    }
}

if (!empty($options['order'])) {
    $events = array_reverse($events);
}
if (!empty($events)) {
    $out['subject'] = $events[0]->post_title;
}
?>


<?php if (!$events) { ?>

<style>
    .noevents {
        font-size: 14px;
        font-style: italic;
        color: #444444;
    }
</style>


    <div inline-class="noevents"><?php echo $options['automated_no_events'] ?></div>


<?php } ?>

<?php
$items = [];
foreach ($events as $event) {
    $item = new stdClass();
    
    $item->url = get_permalink($event->ID);;
    $item->start_date = date_i18n($options['date_format'], strtotime($event->_EventStartDate));
    $item->end_date = date_i18n($options['date_format'], strtotime($event->_EventEndDate));
    $item->start_time = date_i18n($options['time_format'], strtotime($event->_EventStartDate));
    $item->end_time = date_i18n($options['time_format'], strtotime($event->_EventEndDate));

    $item->date = '';
    if ($item->start_date == $item->end_date) {
        $item->date = $item->start_date;
    } else {
        $item->date = $item->start_date . '&nbsp;-&nbsp;' . $item->end_date;
    }

    $item->time = '';
    if ($item->start_time == $item->end_time) {
        $item->time = $item->start_time;
    } else {
        $item->time = $item->start_time . '&nbsp;-&nbsp;' . $item->end_time;
    }
    
    $item->all_day = $event->_EventAllDay == 'yes';

    $item->url = get_permalink($event->ID);
    
    $item->excerpt = tnp_post_excerpt($event, $options['excerpt_length'], true);
    $item->title = get_the_title($event->ID);
    
    // Location
    $item->location = null;
    $location = get_post($event->_EventVenueID);
    if ($location) {
        $item->location = new stdClass();
        $item->location->name = $location->post_title;
        $item->location->city = $location->_VenueCity;
        $item->location->address = $location->_VenueAddress;
    }
    
    // Image
    $item->image = null;
    if (!empty($options['image'])) {
        $item->image = tnp_resize_2x(TNP_Composer::get_post_thumbnail_id($event->ID), [600, 250, true]);
    }
    
    $items[] = $item;
}

switch ($options['layout']) {
    case '1':
        include __DIR__ . '/layout-1.php';
        break;

    case '2':
        include __DIR__ . '/layout-2.php';
        break;
}
